import { Subscription, from } from 'rxjs';
import { startWith, tap } from 'rxjs/operators/index.js';
import { createProxyAndHandleRequests } from '@adminide-stack/extension-api';

class ClientExtensions {
    /**
     * Implements the client side of extensions API.
     *
     * @param connection The connection to the extension host.
     * @param extensionRegistry An observable that emits the set of extensions that should be activated
     *                          upon subscription and whenever it changes.
     */
    constructor(connection, extensionRegistry) {
        this.subscriptions = new Subscription();
        this.proxy = createProxyAndHandleRequests('extensions', connection, this);
        this.subscriptions.add(from(extensionRegistry.activeExtensions)
            .pipe(startWith([]), 
        // bufferCount(2, 1),
        tap((e) => console.log('registrate', e)))
            .subscribe((extensions) => {
            // Diff next state's activated extensions vs. current state's.
            const toActivate = [...extensions]; // cli to avoid mutating state stored by bufferCount
            const toDeactivate = [];
            // if (oldExtensions) {
            //     for (const x of oldExtensions) {
            //         const newIndex = toActivate.findIndex(({ id }) => isEqual(x.id, id));
            //         if (newIndex === -1) {
            //             // Extension is no longer activated
            //             toDeactivate.push(x);
            //         } else {
            //             // Extension is already activated.
            //             toActivate.splice(newIndex, 1);
            //             next.push(x);
            //         }
            //     }
            // }
            /**
             * Deactive extensions that are no longer in use. In practice,
             * {@link activeExtensions} never deactivates extensions, so this will never be
             * called (in the current implementation).
             */
            for (const x of toDeactivate) {
                this.proxy.$deactivateExtension(x.id).catch(err => {
                    console.warn(`Error deactivating extension ${JSON.stringify(x.id)}:`, err);
                });
            }
            // Activate extensions that haven't yet been activated.
            for (const x of toActivate) {
                this.proxy
                    .$activateExtension(x.id, x.scriptURL)
                    .catch(err => console.error(`Error activating extension ${JSON.stringify(x.id)}:`, err));
            }
        }));
    }
    unsubscribe() {
        this.subscriptions.unsubscribe();
    }
}

export { ClientExtensions };
//# sourceMappingURL=client-extensions.js.map
