import * as React from 'react';
import { css } from '@emotion/css';
import { Avatar, Button } from 'antd';
import { CloudDownloadOutlined } from '@ant-design/icons';

const ExetnsionRow = (props) => {
    const { extension, onSelect, onInstall } = props;
    return (React.createElement("div", { onClick: () => onSelect(extension.id), className: css(styles.extension) },
        React.createElement("div", { className: css(styles.icon) },
            React.createElement(Avatar, { size: 56, src: extension.icon }, extension.displayName)),
        React.createElement("div", { className: css(styles.content) },
            React.createElement("div", { className: css(styles.name) }, extension.displayName),
            React.createElement("div", { className: css(styles.description) }, extension.description),
            React.createElement("div", { className: css(styles.author) }, extension.publisherDisplayName || 'author')),
        React.createElement("div", { className: css(styles.actions) },
            React.createElement("div", { className: css(styles.installations) },
                React.createElement(CloudDownloadOutlined, null),
                " ",
                extension.installCount || 0),
            React.createElement("div", { className: css(styles.spacer) },
                React.createElement("small", null, extension.version)),
            React.createElement("div", { className: css(styles.buttons) }, props.isInstalled ? (React.createElement(Button, { onClick: e => {
                    e.stopPropagation();
                    e.preventDefault();
                    props.onRemove(extension.id);
                }, type: "primary", danger: true, size: "small" }, 'Remove')) : (React.createElement(Button, { onClick: e => {
                    e.stopPropagation();
                    e.preventDefault();
                    onInstall(extension.id);
                }, type: "primary", size: "small" }, 'Install'))))));
};
const styles = {
    extension: {
        width: '100%',
        display: 'flex',
        cursor: 'pointer',
        padding: '5px 15px',
        flexDirection: 'row',
        '&:hover': {
            background: 'rgba(0, 0, 0, .1)',
        },
    },
    icon: {
        flexGrow: 0,
    },
    name: {
        fontWeight: 'bold',
        marginBottom: '5px',
    },
    description: {
        marginBottom: '5px',
    },
    author: {
        fontSize: '12px',
        marginBottom: '5px',
    },
    actions: {
        flexGrow: 0,
        display: 'flex',
        flexDirection: 'column',
    },
    content: {
        flexGrow: 1,
        margin: '0 10px',
    },
    installations: {
        flexGrow: 0,
        textAlign: 'right',
    },
    spacer: {
        flexGrow: 1,
        textAlign: 'right',
    },
    buttons: {
        flexGrow: 0,
        textAlign: 'right',
    },
};

export { ExetnsionRow };
//# sourceMappingURL=ExetnsionRow.js.map
