import { ofType } from 'redux-observable';
import { of } from 'rxjs';
import { switchMap, catchError, ignoreElements } from 'rxjs/operators/index.js';
import { LOCATION_CHANGE } from '@cdmbase/redux-data-router';
import { matchRoutes } from '@adminide-stack/platform-client';
import { get } from 'lodash-es';
import { IClientContainerService } from '@adminide-stack/extension-api';
import { useInjection } from '@common-stack/client-react';
import { createController } from '../extensions/controller.js';
import { PlatformContext } from '../platform/context.js';

/* eslint-disable import/no-extraneous-dependencies */
let __extension_controler__;
function useExtensionController() {
    const extensionController = useInjection(IClientContainerService.ExtensionController);
    return extensionController;
}
const isBrowser = typeof document !== 'undefined';
const onLocationChangedToLoadExtEpic = (action$, state$, { apolloClient, routes, services, container, }) => action$.pipe(ofType(LOCATION_CHANGE), switchMap((route) => {
    if (!__extension_controler__ && isBrowser) {
        const branches = matchRoutes(routes, route.payload.location.pathname);
        if (branches) {
            const params = get(branches, 'params');
            if (params) {
                if (params.orgName) {
                    return services.lifecycleService.when(3 /* LifecyclePhase.Restored */).then(() => {
                        const pltContext = new PlatformContext(apolloClient, state$, services);
                        // check again
                        if (!__extension_controler__) {
                            try {
                                __extension_controler__ = createController(pltContext, services);
                                container
                                    .bind(IClientContainerService.ExtensionController)
                                    .toConstantValue(__extension_controler__);
                            }
                            catch (err) {
                                console.error('Extension Binding is failed due ', err);
                            }
                            return of({
                                type: 'EXT_LOADED',
                            });
                        }
                        return of({});
                    });
                }
            }
        }
    }
    return of({});
}), catchError((error) => {
    // Log the error or perform other side effects
    console.error('Error in onLocationChangedToLoadExtEpic:', error);
    // Return a new observable, e.g., an error action
    // Replace 'EXT_LOAD_ERROR' with your actual error action type
    return of({
        type: '@platform/LOG_APPLICATION_ERROR',
        payload: { type: '@platform/LOAD_EXNTSION_ERROR', payload: error },
    });
}), ignoreElements());

export { onLocationChangedToLoadExtEpic, useExtensionController };
//# sourceMappingURL=load-extension-script.js.map
