import { BehaviorSubject, Subscription } from 'rxjs';
import { map } from 'rxjs/operators/index.js';
import 'path';
import '@adminide-stack/extension-api';

/** Base class for provider registries for features. */
class FeatureProviderRegistry {
    constructor() {
        this.entries = new BehaviorSubject([]);
        /** All providers, emitted whenever the set of registered providers changed. */
        this.providers = this.entries.pipe(map(entries => entries.map(({ provider }) => provider)));
    }
    registerProvider(registrationOptions, provider) {
        return this.registerProviders([{ registrationOptions, provider }]);
    }
    /**
     * Bulk-register providers. This is useful when registering an initial set of providers. Registering them all
     * at once means there is only one emission from {@link FeatureProviderRegistry#entries} (instead of one per
     * entry).
     */
    registerProviders(entries) {
        this.entries.next([...this.entries.value, ...entries]);
        return new Subscription(() => {
            this.entries.next([...this.entries.value.filter(entry => !entries.includes(entry))]);
        });
    }
}

export { FeatureProviderRegistry };
//# sourceMappingURL=registry.js.map
