import { BehaviorSubject } from 'rxjs';
import { CommandRegistry } from './command-service.js';
import { ExtensionsService } from './extensions-service.js';
import { EMPTY_ENVIRONMENT } from '../api/environment.js';
import { editorWindowsService } from './windows-service.js';
import { PanelViewProviderRegistry } from './panel-views.js';

/**
 * Services is a container for all services used by the client applicatino.
 */
class Services {
    constructor(platformContext, internalService) {
        this.platformContext = platformContext;
        this.internalService = internalService;
        this.environment = new BehaviorSubject(EMPTY_ENVIRONMENT);
        this.windows = editorWindowsService(this.platformContext);
        // not needed as we can use configurationService
        this.contextKeyService = this.internalService.contextKeyService;
        // public readonly resourceContextKey = this.internalService.resourceContextKey;
        this.lifecycleService = this.internalService.lifecycleService;
        this.model = this.internalService.model;
        this.viewer = this.internalService.viewer;
        this.extensions = new ExtensionsService(this.platformContext, this.model);
        this.commands = new CommandRegistry();
        this.contribution = this.internalService.contribution;
        this.panelView = new PanelViewProviderRegistry();
        this.organizationContextService = this.internalService.organizationContextService;
        this.configurationService = this.internalService.configurationService;
        this.registry = this.internalService.registry;
        this.preferenceService = this.internalService.preferenceService;
    }
}

export { Services };
//# sourceMappingURL=services.js.map
