import { get } from 'lodash-es';
import { createSelector } from 'reselect';
import { find, propEq, whereEq } from 'ramda';

/* eslint-disable import/no-extraneous-dependencies */
/* tslint:disable */
const editSelect = (state) => get(state, 'files_stack__edit');
const editorsSelect = createSelector(editSelect, (edit) => get(edit, 'editors', []));
const editingFilesSelect = createSelector(editSelect, (edit) => get(edit, 'editingFiles', []));
const openingFilesSelect = createSelector(editSelect, (edit) => get(edit, 'openingFiles', []));
const activeEditorIdSelect = createSelector(editSelect, (edit) => get(edit, 'activeEditorId', null));
const lastEditorIdSelect = createSelector(editorsSelect, (editors) => editors[editors.length - 1] || 0);
const contentSelect = createSelector(openingFilesSelect, editingFilesSelect, activeEditorIdSelect, (openingFiles, editingFiles, editorId) => getFileContent(openingFiles, editingFiles, editorId));
const fromStore = (store, selector) => () => selector(store.getState());
const getFileContent = (openingFiles, editingFiles, editorId) => {
    const editingFile = find(propEq('editorId', editorId))(editingFiles);
    if (editingFile) {
        return find(whereEq({
            resource: editingFile.resource,
            name: editingFile.name,
            editorId,
        }))(openingFiles);
    }
    return null;
};
const editorWindowsService = ({ store, reduxState$, }) => ({
    editors: fromStore(store, editorsSelect),
    content: fromStore(store, contentSelect),
    lastEditorId: fromStore(store, lastEditorIdSelect),
    openingFiles: fromStore(store, openingFilesSelect),
    editingFiles: fromStore(store, editingFilesSelect),
    activeEditorId: fromStore(store, activeEditorIdSelect),
    selectEditorWindow: (content) => { },
    openEditorWindow: (content) => /** store.dispatch(EditorActions.openFileAction(content as any) */ { },
    closeEditorWindow: (content) => /** store.dispatch(EditorActions.removeEditAction(content)) */ { },
    updateEditorWindow: (content) => /** store.dispatch(EditorActions.updateEditorContentAction(content as any) */ { },
});

export { editorWindowsService, getFileContent };
//# sourceMappingURL=windows-service.js.map
