import { Observable, fromEvent } from 'rxjs';
import { filter } from 'rxjs/operators/index.js';

class LocalStorageSubject extends Observable {
    constructor(key, defaultValue) {
        super(subscriber => {
            subscriber.next(this.value);
            return fromEvent(window, 'storage')
                .pipe(filter(event => event.key === key))
                .subscribe(event => {
                subscriber.next(parseValue(event.newValue, defaultValue));
            });
        });
        this.key = key;
        this.defaultValue = defaultValue;
    }
    next(value) {
        const v = JSON.stringify(value);
        localStorage.setItem(this.key, v);
        // Does not set oldValue or other StorageEventInit keys because we don't need them.
        window.dispatchEvent(new StorageEvent('storage', { key: this.key, newValue: v }));
    }
    get value() {
        return parseValue(localStorage.getItem(this.key), this.defaultValue);
    }
}
function parseValue(v, defaultValue) {
    if (v === null) {
        return defaultValue;
    }
    try {
        return JSON.parse(v);
    }
    catch (err) {
        return defaultValue;
    }
}

export { LocalStorageSubject };
//# sourceMappingURL=local-storage-subject.js.map
